Orphan

Struct Orphan 

pub struct Orphan<T> { /* private fields */ }
A container for a single, non-collection value stored on disk.

Orphan is suitable for storing simple data types like integers, enums, etc.

Implementations

Source

impl<T> Orphan<T>
where T: ValueEnDe,

pub unsafe fn shadow(&self) -> Self

Creates a “shadow” copy of the Orphan instance.

Safety

This API breaks Rust’s semantic safety guarantees. Use only in a race-free environment.

pub unsafe fn from_bytes(s: impl AsRef<[u8]>) -> Self

Creates an Orphan from a byte slice.

Safety

This function is unsafe and assumes the byte slice is a valid representation.

pub fn as_bytes(&self) -> &[u8]

Returns the byte representation of the Orphan.

pub fn new(v: T) -> Self

Creates a new Orphan with an initial value.

pub fn get_value(&self) -> T

Retrieves a clone of the inner value.

pub fn set_value(&mut self, v: &T)

Sets the inner value.

pub fn is_uninitialized(&self) -> bool

Checks if the Orphan is uninitialized.

pub fn initialize_if_empty(&mut self, v: T)

Initializes the Orphan with a value if it is currently empty.

pub fn get_mut(&mut self) -> ValueMut<'_, T>

Retrieves a mutable handler for the value.

This is the recommended way to modify the value.

Example
let mut o = Orphan::new(10);
*o.get_mut() = 20;
assert_eq!(o.get_value(), 20);
pub fn is_the_same_instance(&self, other_hdr: &Self) -> bool

Checks if this Orphan instance is the same as another.