pub type RawBytes = Vec<u8>;Expand description
A type alias for a vector of bytes, commonly used for raw data.
Aliased Type
pub struct RawBytes { /* private fields */ }Trait Implementations
Sourceimpl KeyEnDeOrdered for RawBytes
impl KeyEnDeOrdered for RawBytes
Sourcefn into_bytes(self) -> RawBytes
fn into_bytes(self) -> RawBytes
Consumes the key and encodes it into a byte vector.
Sourcefn from_slice(b: &[u8]) -> Result<Self>
fn from_slice(b: &[u8]) -> Result<Self>
Decodes a key from a byte slice.
Sourcefn from_bytes(b: RawBytes) -> Result<Self>
fn from_bytes(b: RawBytes) -> Result<Self>
Consumes a byte vector and decodes it into a key.